# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`libvirt`](#libvirt): this is the main class, used configure libvirt.
* [`libvirt::config`](#libvirtconfig): Installs configuration files
* [`libvirt::install`](#libvirtinstall): Installs the required packages and files
* [`libvirt::manage_domains_config`](#libvirtmanage_domains_config): Installs configuration files for manage-domains script
* [`libvirt::profiles`](#libvirtprofiles): this class loads all the available profiles for usage in domain.pp
* [`libvirt::service`](#libvirtservice): Installs services

### Defined types

* [`libvirt::domain`](#libvirtdomain): Define a new libvirt domain. The name of the domain is
the resource name. The domain_title attribute allows to
to set a free text title.
* [`libvirt::network`](#libvirtnetwork): Define a new libvirt network. The name of the network is
the resource name.
* [`libvirt::nwfilter`](#libvirtnwfilter): libvirt::nwfilter  Define a new libvirt nwfilter. The name of the nwfilter is the resource name. It expects an ip address and will set up fir

### Resource types

* [`libvirt_pool`](#libvirt_pool): Manages libvirt pools
* [`libvirtd_conf`](#libvirtd_conf): setting name to manage value in libvirtd.conf
* [`libvirtd_default`](#libvirtd_default): setting name to manage default for libvirtd

### Functions

* [`libvirt::get_merged_profile`](#libvirtget_merged_profile): merges profiles
* [`libvirt_generate_mac`](#libvirt_generate_mac): compute sha1 hash of all keys concatenated, only the first 6 hex digits will be used
* [`libvirt_generate_mac_addresses`](#libvirt_generate_mac_addresses): Generates MAC addresses for all interfaces in the array which do not yet have an address specified. The MAC addresses are based on the domain
* [`libvirt_generate_uuid`](#libvirt_generate_uuid): compute sha1 hash of all keys concatenated

## Classes

### `libvirt`

Libvirt (http://libvirt.org/) Puppet module

#### Examples

##### using a drbd hook

```puppet
class { 'libvirt':
  qemu_hook => 'drbd',
  qemu_conf => {
    'vnc_listen' => '0.0.0.0'
  }
}
```

#### Parameters

The following parameters are available in the `libvirt` class.

##### `service_name`

Data type: `String`

Service name for libvirt. The default value is Distribution specific.
Only set this if your setup differs from the packages provided by
your distribution.

Default value: `'libvirtd'`

##### `service_ensure`

Data type: `String`

Whether the service should be running.
Defaults to 'running'

Default value: `'running'`

##### `service_enable`

Data type: `Boolean`

Whether the service should be enabled.
Defaults to true

Default value: ``true``

##### `manage_service`

Data type: `Boolean`

Whether the service should be managed by this module.
Defaults to true

Default value: ``true``

##### `libvirt_package_names`

Data type: `Array`

Array of the libvirt packages to install.
Required, see hiera data directory for defaults

Default value: `[]`

##### `qemu_hook_packages`

Data type: `Hash`

Hash of Arrays of hook specific packages to install
Defaults to {}

Default value: `{}`

##### `qemu_conf`

Data type: `Hash`

Hash of key/value pairs you want to put in qemu.conf file.

Default value: `{}`

##### `qemu_hook`

Data type: `String`

QEMU hook to install. The only currently available hook is a script
to setup DRBD resources. Valid values are 'drbd' or '' (=no hook).
Defaults to ''.

Default value: `''`

##### `qemu_hook_packages`

Hash of Arrays of hook specific packages to install
see hiera data directory for defaults

Default value: `{}`

##### `create_networks`

Data type: `Hash`

Hash of networks to create with libvirt::network
Defaults to {}

Default value: `{}`

##### `create_domains`

Data type: `Hash`

Hash of domains to create with libvirt::domain
Defaults to {}

Default value: `{}`

##### `create_nwfilters`

Data type: `Hash`

Hash of nwfilters to create with libvirt::nwfilter
Defaults to {}

Default value: `{}`

##### `evacuation`

Data type: `String`

Default evacuation policy to shutdown or migrate all domains on a host.
Valid values are 'migrate', 'save' and 'shutdown'. This can be overriden
on a per domain basis. The default value is 'migrate'.
<p>Only useful together with the drbd qemu_hook in setups of two
redundant virtualization hosts synchronized over DRBD. They
have no effect if qemu_hook is not set to drbd.

Default value: `'migrate'`

##### `max_job_time`

Data type: `String`

Default maximum job time in seconds when migrating, saving or shuting down
domains with the manage-domains script. This can be overriden on a per
domain basis. The default is 120.
<p>Only useful together with the drbd qemu_hook in setups of two
redundant virtualization hosts synchronized over DRBD. They
have no effect if qemu_hook is not set to drbd.

Default value: `'120'`

##### `suspend_multiplier`

Data type: `String`

Default suspend_multiplier for migrating domains with the manage-domains
script. This can be overriden on a per domain basis. The default is 5.
<p>Only useful together with the drbd qemu_hook in setups of two
redundant virtualization hosts synchronized over DRBD. They
have no effect if qemu_hook is not set to drbd.

Default value: `'5'`

##### `migration_url_format`

Data type: `String`

url format for to use for migration. default is ssh
possible values:
ssh: gives an url: 'qemu+ssh://%s/system'
tls: gives an url: 'qemu+tls://%s/system'
alias: sepcify the url as an alias in /etc/libvirt.conf

Default value: `'ssh'`

##### `uri_aliases`

Data type: `Array`

define aliases for a client to connect
defaults to []

Default value: `[]`

##### `uri_default`

Data type: `String`

the default url to use.
defaults to '' (which means the system default is used)

Default value: `''`

##### `default_conf`

Data type: `Hash`

Hash to add config to /etc/default/libvirtd (Debian) or
/etc/sysconfig/libvirtd (RedHat)
Defaults to {}

Default value: `{}`

##### `libvirtd_conf`

Data type: `Hash[Optional[String],Variant[String,Integer,Array]]`

Hash to add config to /etc/libvirt/libvirtd.conf
Defaults to {}

Default value: `{}`

##### `config_dir`

Data type: `String`

the directory for configurations.
Defaults to '/etc/libvirt'

Default value: `'/etc/libvirt'`

##### `manage_domains_config`

Data type: `String`

configuration file for managing domains.
Defaults to '/etc/manage-domains.ini'

Default value: `'/etc/manage-domains.ini'`

##### `drop_default_net`

Data type: `Boolean`

Boolean, don't create default network and bridge (virbr0)
Defaults to false

Default value: ``false``

##### `diff_dir`

Data type: `String`

if this is set to a path, the directory is created and
the xmls generated for the domains are kept and diffs
are shown on changes by puppet.
usefull for development (or on upgrade)
defaults to '' (== disabled)

Default value: `''`

### `libvirt::config`

libvirt::config

* **Note** parameter are inherited from ::libvirt and documented there.

#### Parameters

The following parameters are available in the `libvirt::config` class.

##### `qemu_hook`

Data type: `String`

source name for qemu hook

Default value: `$libvirt::qemu_hook`

##### `qemu_conf`

Data type: `Hash`

configuration that goes into qemu.conf

Default value: `$libvirt::qemu_conf`

##### `uri_aliases`

Data type: `Array`

uri alias from libvirt.conf

Default value: `$libvirt::uri_aliases`

##### `uri_default`

Data type: `String`

uri default from libvirt.conf

Default value: `$libvirt::uri_default`

##### `default_conf`

Data type: `Hash`

defaults for libvirtd.conf

Default value: `$libvirt::default_conf`

##### `libvirtd_conf`

Data type: `Hash[Optional[String],Variant[String,Integer,Array]]`

libvirtd.conf configs

Default value: `$libvirt::libvirtd_conf`

##### `config_dir`

Data type: `String`

directory for configs

Default value: `$libvirt::config_dir`

### `libvirt::install`

libvirt::install

#### Parameters

The following parameters are available in the `libvirt::install` class.

##### `qemu_hook`

Data type: `String`

QEMU hook to install. The only currently available hook is a script
to setup DRBD resources. Valid values are 'drbd' or '' (=no hook).
Default inherited from ::libvirt class

Default value: `$libvirt::qemu_hook`

##### `packages`

Data type: `Array`

Array of the libvirt package names to install.
Default inherited from ::libvirt class

Default value: `$libvirt::libvirt_package_names`

##### `qemu_hook_packages`

Data type: `Hash`

Hash of Arrays of hook specific packages to install
Default inherited from ::libvirt class

Default value: `$libvirt::qemu_hook_packages`

##### `package_ensure`

Data type: `String`

What state the packages should be in.
Defaults to 'installed'

Default value: `'installed'`

### `libvirt::manage_domains_config`

libvirt::manage_domains_config

#### Parameters

The following parameters are available in the `libvirt::manage_domains_config` class.

##### `manage_domains_config`

Data type: `String`

file where the manage_domains configuration is.
Defaults to $libvirt::manage_domains_config
Remark: if you change this, you also have to change in
libvirt::domain define

Default value: `$libvirt::manage_domains_config`

### `libvirt::profiles`

libvirt::profiles

#### Parameters

The following parameters are available in the `libvirt::profiles` class.

##### `devices`

Data type: `Hash`

devices profiles to load

##### `domconf`

Data type: `Hash`

domconf profiles to load

### `libvirt::service`

libvirt::service

#### Parameters

The following parameters are available in the `libvirt::service` class.

##### `service_name`

Data type: `String`

Service name for libvirt. The default value is Distribution specific
and inherited from ::libvirt class.

Default value: `$libvirt::service_name`

##### `service_ensure`

Data type: `String`

Whether the service should be running.
Defaults to 'running'

Default value: `$libvirt::service_ensure`

##### `service_enable`

Data type: `Boolean`

Whether the service should be enabled.
Defaults to true

Default value: `$libvirt::service_enable`

##### `manage_service`

Data type: `Boolean`

Whether the service should be managed at all.
Defaults to true

Default value: `$libvirt::manage_service`

## Defined types

### `libvirt::domain`

libvirt::domain

* **Note** Most parameters are modeled after their equivalents in the libvirt
domain XML definition. See http://libvirt.org/formatdomain.html
for more information.

#### Parameters

The following parameters are available in the `libvirt::domain` defined type.

##### `type`

Data type: `String`

Specify the hypervisor used for running the domain.
The allowed values are driver specific, but include "xen", "kvm", "qemu" and "lxc"
Defaults to 'kvm'

Default value: `'kvm'`

##### `domain_title`

Data type: `String`

Free text title of the domain. Defaults to ''.

Default value: `''`

##### `description`

Data type: `String`

Free text description of the domain. Defaults to ''.

Default value: `''`

##### `uuid`

Data type: `String`

UUID for the domain. The default is the uuid, generated
with puppet.

Default value: `libvirt_generate_uuid($name)`

##### `boot`

Data type: `String`

Default boot device. Valid values are any accepted by libvirt or the string
'per-device' to set individual boot orders on disks or interfaces.
Defaults to 'hd'.

Default value: `'hd'`

##### `disks`

Data type: `Array`

Array of hashes defining the disks of this domain. Defaults to no disks
at all. The hashes support the following keys:
  * type:       Disk type, supported types are 'file', 'block', 'network' and
                'volume'.
  * device:     Disk device type exposed to the guest. Supported values are
                'floppy', 'disk', 'cdrom' and 'lun'.
  * bus:        Target bus, defaults to 'virtio'.
  * source:     Hash of source parameters. The supported hash keys vary by the
                type of disk:
                file:    'file' key to specify the pathname of the source file
                         backing this disk.
                block:   'dev' key to specify the pathname to the block device
                         backing this disk.
                network: 'protocol' and 'name'
                volume:  'pool' and 'volume'
 * driver:      Hash of driver parameters. Defaults to raw disks images, no caching
                and native io. Use {'name' => 'qemu', 'type' => 'qcow2'} for QCOW2
                images.
                See the libvirt domain XML documentation for all possible values.
 * boot_order:  Integer starting at 1 for the highest priority (shared with
                interfaces).

Default value: `[]`

##### `interfaces`

Data type: `Array`

Array of hashes defining the network interfaces of this domain. Defaults to
no network interfaces.
The hashes support the following keys:
  * mac:        MAC address of the interface. Without a mac key, a random
                address will be assigned by libvirt. The MAC address should
                start with 52:54:00.
  * network:    libvirt network to attach to (mandatory).
  * portgroup:  portgroup to attach to (optional).
  * type:       Type of network card. Defaults to 'virtio'.
  * boot_order: Integer starting at 1 for the highest priority (shared with
                disks).

Default value: `[]`

##### `autostart`

Data type: `Boolean`

Wheter the libvirt autostart flag should be set. Defaults to true. Autostart
domains are started if the host is booted.

Default value: ``true``

##### `dom_profile`

Data type: `String`

profile to use for $domconf.
Defaults to 'default' which is defined in data/profiles/xxx.yaml
A profile is a predefined set of parameters for a vm.
see class libvirt::profiles for additional information.

Default value: `'default'`

##### `domconf`

Data type: `Hash`

the generic domain configuration to activate for vm.
this parameter is merged with the choosen profile,
($libvirt::profiles::domconf)
to generate the final configuration.
Defaults to {} which does not change the profile.
see also libvirt::profiles for how to use profiles

Default value: `{}`

##### `devices_profile`

Data type: `String`

profile to use for $devices.
Defaults to 'default' which is defined in data/profiles/xxx.yaml
A profile is a predefined set of parameters for a vm.
see class libvirt::profiles for additional information.

Default value: `'default'`

##### `devices`

Data type: `Hash`

devices to attach to the vm
this parameter is merged with the choosen profile,
($libvirt::profiles::devices)
to generate the final configuration.
Defaults to {} which does not change the profile.
see also libvirt::profiles for how to use profiles

Default value: `{}`

##### `additionaldevices`

Data type: `Hash`

additional devices to attach to the vm
Same format as $devices, but without merging.
Defaults to {}

Default value: `{}`

##### `default_host`

Data type: `Optional[String]`

FQDN for the default host of this domain. The manage-domains script uses
this value to move a domain to it's default host if it's running elsewhere.
<p>Only useful together with the drbd qemu_hook in setups of two
redundant virtualization hosts synchronized over DRBD. They
have no effect if qemu_hook is not set to drbd.

Default value: ``undef``

##### `evacuation`

Data type: `Optional[String]`

Evacuation policy for this domain. Valid values are 'migrate', 'save' and
'shutdown'. The default is to not set a value and to use the global default.
<p>Only useful together with the drbd qemu_hook in setups of two
 redundant virtualization hosts synchronized over DRBD. They
 have no effect if qemu_hook is not set to drbd.

Default value: ``undef``

##### `max_job_time`

Data type: `Optional[String]`

Maximum job time in seconds when migrating, saving or shuting down this
domain with the manage-domains script. The default is to not set a value
and to use the global default.
<p>Only useful together with the drbd qemu_hook in setups of two
 redundant virtualization hosts synchronized over DRBD. They
 have no effect if qemu_hook is not set to drbd.

Default value: ``undef``

##### `suspend_multiplier`

Data type: `Optional[String]`

suspend_multiplier for migrating domains with the manage-domains
script. The default is to not set a value and to use the global default.
<p>Only useful together with the drbd qemu_hook in setups of two
redundant virtualization hosts synchronized over DRBD. They
have no effect if qemu_hook is not set to drbd.

Default value: ``undef``

##### `max_memory`

Data type: `Optional[Any]`

Deprecated: Maximum amount of memory that can be allocated to the domain.
Example (yaml):
  domconf:
    memory:
      attrs:
        unit: 'MiB'
      values: 2000
**This parameter is deprecated, if set, the manifest will fail**

Default value: ``undef``

##### `initial_memory`

Data type: `Optional[Any]`

Initial memory allocation for the domain. Defaults to max_memory.
Deprecation notice: use $domconf (or profile) to set.
Example (yaml):
  domconf:
    currentMemory:
      attrs:
        unit: 'MiB'
      values: 1000
**This parameter is deprecated, if set, the manifest will fail**

Default value: ``undef``

##### `cpus`

Data type: `Optional[Any]`

Number of virtual CPUs for the domain. Defaults to '1'.
Deprecation notice: use $domconf (or profile) to set.
Example (yaml):
  domconf:
    vcpu:
      values: 1
**This parameter is deprecated, if set, the manifest will fail**

Default value: ``undef``

##### `bootmenu`

Data type: `Optional[Any]`

Wheter the boot menu option should be available or not. Defaults to true.
Deprecation notice: use $domconf if you want to disable the bootmenu
Example (yaml):
  domconf:
    os:
      bootmenu:
        attrs:
          enable: 'no'
**This parameter is deprecated, if set, the manifest will fail**

Default value: ``undef``

##### `machine_type`

Data type: `Optional[Any]`

Machine type to use, i.e.
  * "pc" - Standard PC (i440FX + PIIX, 1996)
  * "q35" - Standard PC (Q35 + ICH9, 2009)
Deprecation notice: use $domconf if you want to set the machine type
**This parameter is deprecated, if set, the manifest will fail**

Default value: ``undef``

##### `cpu_model`

Data type: `Optional[Any]`

CPU model to emulate. Valid values are any cpu model accepted by libvirt or
the special values 'host-model' and 'host-passthrough'. See
http://libvirt.org/formatdomain.html#elementsCPU for details. Defaults to
not set a CPU at all and let libvirt choose. The values 'host-model' and
'host-passthrough' prevent migrations from working.
Deprecation notice: use $domconf (or profile) if you want to set the machine type
Example (yaml):
  domconf:
    cpu:
      attrs:
        mode: 'custom'
      values:
        model: 'SandyBridge'
**This parameter is deprecated, if set, the manifest will fail**

Default value: ``undef``

### `libvirt::network`

libvirt::network

* **Note** Most parameters are modeled after their equivalents in the libvirt
network XML definition. See http://libvirt.org/formatnetwork.html
for more information.

#### Parameters

The following parameters are available in the `libvirt::network` defined type.

##### `ensure`

Data type: `String`



Default value: `'present'`

##### `bridge`

Data type: `String`

Name of the bridge device to use for this network.

Default value: `''`

##### `forward_mode`

Data type: `String`

Network forward mode. Valid modes are 'nat', 'route', 'bridge', 'private',
'vepa', 'passthrough' and 'hostdev'. The default is 'bridge'.

Default value: `'bridge'`

##### `virtualport_type`

Data type: `Optional[String]`

Set this to 'openvswitch' for an Open vSwitch bridge. Leave undefined
otherwise.

Default value: ``undef``

##### `portgroups`

Data type: `Array`

Array of hashes defining portgroups. This only works for Open vSwitch
networks. The hash supports the following keys:
* name:     Name of the portgroup.
* trunk:    Set to true if this is a trunk port. In this case, the
            vlan_tag element must contain an array of allowed VLAN
            tags.
* vlan_tag: VLAN tag for this portgroup.

Default value: `[]`

##### `autostart`

Data type: `Boolean`

Wheter to start this network on boot or not. Defaults to true.

Default value: ``true``

##### `forward_dev`

Data type: `Optional[String]`

The interface to forward, useful in bridge and route mode

Default value: ``undef``

##### `forward_interfaces`

Data type: `Array`

An array of interfaces to forwad

Default value: `[]`

##### `ip_address`

Data type: `Optional[String]`

The ip address for the device

Default value: ``undef``

##### `ip_netmask`

Data type: `Optional[String]`

The netmask for the ip address

Default value: ``undef``

##### `dhcp_start`

Data type: `Optional[String]`

Optional dhcp range start

Default value: ``undef``

##### `dhcp_end`

Data type: `Optional[String]`

Optional dhcp range end

Default value: ``undef``

##### `dns_enable`

Data type: `Optional[String]`

Set this to 'no' to disable the DNS service. Leave undefined otherwise.

Default value: ``undef``

##### `mtu`

Data type: `Optional[Integer]`

Set a custom mtu value. Default is 1500.

Default value: ``undef``

### `libvirt::nwfilter`

libvirt::nwfilter

Define a new libvirt nwfilter. The name of the nwfilter is
the resource name. It expects an ip address and will set up
firewalling that restricts inbound traffic to the given port
numbers.

#### Parameters

The following parameters are available in the `libvirt::nwfilter` defined type.

##### `uuid`

Data type: `String`

The libvirt UUID, optional.

Default value: `libvirt_generate_uuid($name)`

##### `ip`

Data type: `Optional[String]`

The VM's IP address, mandatory.

Default value: ``undef``

##### `publictcpservices`

Data type: `Array`

An array with portnumbers that should be accessible over
TCP from anywhere

Default value: `[]`

##### `publicudpservices`

Data type: `Array`

An array with portnumbers that should be accessible over
UDP from anywhere

Default value: `[]`

##### `customtcprules`

Data type: `Array`

An array with rules that allow traffic to a specific TCP
port from a specific address. Syntax:
`[{remote_ip => port}, ... ]`

Default value: `[]`

##### `customudprules`

Data type: `Array`

An array with rules that allow traffic to a specific UDP
port from a specific address. Syntax:
`[{remote_ip => port}, ... ]`

Default value: `[]`

## Resource types

### `libvirt_pool`

Manages libvirt pools

#### Examples

##### 

```puppet
libvirt_pool { 'default' :
  ensure => absent
}
```

##### 

```puppet
libvirt_pool { 'mydirpool' :
  ensure    => present,
  active    => true,
  autostart => true,
  type      => 'dir',
  target    => '/tmp/mypool',
}
```

##### 

```puppet
libvirt_pool { 'mydirpool2' :
  ensure       => present,
  active       => true,
  autostart    => true,
  type         => 'dir',
  target       => '/tmp/mypool2',
  target_owner => 107,
  target_group => 107,
  target_mode  => '0755',
}

libvirt_pool { 'vm_storage':
  ensure    => 'present',
  active    => 'true',
  type      => 'logical',
  sourcedev => ['/dev/sdb', '/dev/sdc'],
  target    => '/dev/vg0'
}
```

#### Properties

The following properties are available in the `libvirt_pool` type.

##### `active`

Valid values: ``true``, ``false``

Whether the pool should be started.

Default value: `true`

##### `autostart`

Valid values: ``true``, ``false``

Whether the pool should be autostarted.

Default value: `false`

##### `ensure`

Valid values: `present`, `absent`

Manages the creation or the removal of a pool
`present` means that the pool will be defined and created
`absent` means that the pool will be purged from the system

Default value: `present`

#### Parameters

The following parameters are available in the `libvirt_pool` type.

##### `name`

Valid values: `%r{^\S+$}`

namevar

The pool name.

##### `provider`

The specific backend to use for this `libvirt_pool` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### `sourcedev`

Valid values: `%r{(\/)?(\w)}`

The source device.

##### `sourceformat`

Valid values: `auto`, `nfs`, `glusterfs`, `cifs`

The source format.

##### `sourcehost`

Valid values: `%r{^\S+$}`

The source host.

##### `sourcename`

Valid values: `%r{^\S+$}`

The source name.

##### `sourcepath`

Valid values: `%r{(\/)?(\w)}`

The source path.

##### `target`

Valid values: `%r{(\/)?(\w)}`

The target.

##### `target_group`

Valid values: `%r{^\S+$}`

The group of the target dir or filesystem

##### `target_mode`

Valid values: `%r{^[0-7]{4}$}`

The mode of the target dir or filesystem

##### `target_owner`

Valid values: `%r{^\S+$}`

The owner of the target dir or filesystem

##### `type`

Valid values: `dir`, `netfs`, `fs`, `logical`, `disk`, `iscsi`, `mpath`, `rbd`, `sheepdog`

The pool type.

### `libvirtd_conf`

setting name to manage value in libvirtd.conf

#### Properties

The following properties are available in the `libvirtd_conf` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `value`

The value of the setting to be defined.

#### Parameters

The following parameters are available in the `libvirtd_conf` type.

##### `name`

Valid values: `%r{\S+}`

namevar

setting name to manage value in libvirtd.conf

##### `provider`

The specific backend to use for this `libvirtd_conf` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### `secret`

Valid values: ``true``, ``false``

Whether to hide the value from Puppet logs. Defaults to `false`.

Default value: ``false``

### `libvirtd_default`

setting name to manage default for libvirtd

#### Properties

The following properties are available in the `libvirtd_default` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `value`

The value of the setting to be defined.

#### Parameters

The following parameters are available in the `libvirtd_default` type.

##### `name`

Valid values: `%r{\S+}`

namevar

setting name to manage default for libvirtd

##### `provider`

The specific backend to use for this `libvirtd_default` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### `secret`

Valid values: ``true``, ``false``

Whether to hide the value from Puppet logs. Defaults to `false`.

Default value: ``false``

## Functions

### `libvirt::get_merged_profile`

Type: Puppet Language

function to merge profiles.

A profile is a hash of values. A profile can depend on another profile.
The base for a profile can be configured in the profiles data:
$data['profileconfig']['base'], which should reference another profile.
Merging is per default done using a hash merge. Alternativ deep_merge can
configured for a profile by setting $data['profileconfig']['merge'] to 'deep'.
(remark: this is NOT the deep_merge of hiera, but of puppetlab-stdlib,
see https://github.com/puppetlabs/puppetlabs-stdlib/blob/master/REFERENCE.md#deep_merge)

* **Note** The profiles are computed using recursion.
$data['profileconfig'] is removed from the resulting hash.

#### `libvirt::get_merged_profile(Hash $profile_hash, String $profile)`

function to merge profiles.

A profile is a hash of values. A profile can depend on another profile.
The base for a profile can be configured in the profiles data:
$data['profileconfig']['base'], which should reference another profile.
Merging is per default done using a hash merge. Alternativ deep_merge can
configured for a profile by setting $data['profileconfig']['merge'] to 'deep'.
(remark: this is NOT the deep_merge of hiera, but of puppetlab-stdlib,
see https://github.com/puppetlabs/puppetlabs-stdlib/blob/master/REFERENCE.md#deep_merge)

Returns: `Any` the computed profile

##### `profile_hash`

Data type: `Hash`

all the profiles

##### `profile`

Data type: `String`

Name of the computed profile to return

### `libvirt_generate_mac`

Type: Ruby 3.x API

compute sha1 hash of all keys concatenated, only the first 6
hex digits will be used

#### `libvirt_generate_mac()`

compute sha1 hash of all keys concatenated, only the first 6
hex digits will be used

Returns: `Any` a mac address

### `libvirt_generate_mac_addresses`

Type: Ruby 3.x API

Generates MAC addresses for all interfaces in the array which do not yet have an
address specified. The MAC addresses are based on the domain name, network and
portgroup.

#### `libvirt_generate_mac_addresses(Any $hash)`

Generates MAC addresses for all interfaces in the array which do not yet have an
address specified. The MAC addresses are based on the domain name, network and
portgroup.

Returns: `Any` the interfacess with mac address

##### `hash`

Data type: `Any`

of interfaces

### `libvirt_generate_uuid`

Type: Ruby 3.x API

compute sha1 hash of all keys concatenated

#### `libvirt_generate_uuid()`

compute sha1 hash of all keys concatenated

Returns: `String` the computed uuid

